package com.lifepay.lifepayrp750xdemo.activities;

import android.view.View;
import android.widget.Button;

import com.lifepay.lib.LifePayApi;
import com.lifepay.lifepayrp750xdemo.TestData;
import com.lifepay.lifepayrp750xdemo.utils.ActivityUtils;
import com.lifepay.lifepayrp750xdemo.R;
import com.lifepay.lifepayrp750xdemo.activities.base.BaseFragmentActivity;
import com.lifepay.lifepayrp750xdemo.activities.base.FBaseMenuBar;
import com.lifepay.lifepayrp750xdemo.activities.rp750x.RP750xPaymentActivity_;
import com.lifepay.lifepayrp750xdemo.activities.rp750x.refund.RP750xRefundActivity_;

import org.androidannotations.annotations.AfterViews;
import org.androidannotations.annotations.Click;
import org.androidannotations.annotations.EActivity;
import org.androidannotations.annotations.FragmentById;
import org.androidannotations.annotations.ViewById;

@EActivity(R.layout.activity_main)
public class MainActivity extends BaseFragmentActivity {

    @FragmentById
    protected FBaseMenuBar fMenuBar;

    @ViewById
    protected Button btnRefund;
    @ViewById
    protected Button btnClear;

    @AfterViews
    protected void init() {
        fMenuBar.hideBackBtn();

        //Включение тестового режима, чтобы транзакции ходили через тестовые сервера.
        LifePayApi.getInstance().changeTestMode(context, true);
        //Если не было платежа, то кнопку возврата прячем, т.к. непонятно, что возвращать.
        if (TestData.TRANSACTION_INFO == null) {
            btnRefund.setVisibility(View.GONE);
        }
        //Прячем кнопку отвязки приложения от конкретного терминала, если связанного терминала нету.
        //Библиотека запоминает конкретный терминал, после успешного подключения к терминалу
        //И в дальнейшем будет подключаться сразу к нему.
        //Не путать с сопряжением, которое происходит на уровне операционной системы.
        if (!LifePayApi.getInstance().pinPad().hasLinkedDevice(context)) {
            btnClear.setVisibility(View.GONE);
        }
    }

    @Click(R.id.btnPayment)
    public void onPaymentClick() {
        ActivityUtils.startActivity(this, RP750xPaymentActivity_.class);
    }

    @Click(R.id.btnRefund)
    public void onRefundClick() {
        ActivityUtils.startActivity(this, RP750xRefundActivity_.class);
    }

    @Click(R.id.btnClear)
    public void onClearClick() {
        //Если это вызвать, то библиотека при старте транзакции предложит выбрать терминал из списка сопряженных терминалов.
        LifePayApi.getInstance().pinPad().removeLinkedDevice(this);
        btnClear.setVisibility(View.GONE);
    }

    @Override
    public void back() {

    }
}
