package com.lifepay.lifepayrp750xdemo.activities.base;

import org.androidannotations.annotations.AfterViews;
import org.androidannotations.annotations.Click;
import org.androidannotations.annotations.EFragment;
import org.androidannotations.annotations.ViewById;

import android.content.Context;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Point;
import android.graphics.PorterDuff;
import android.support.v4.app.FragmentActivity;
import android.text.TextUtils;
import android.util.Log;
import android.util.TypedValue;
import android.view.Display;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewTreeObserver;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.RelativeLayout.LayoutParams;
import android.widget.TextView;

import com.lifepay.lib.logic.Global;
import com.lifepay.lifepayrp750xdemo.R;

@EFragment
public class FBaseSignature extends BaseFragment {

    @ViewById
    protected TextView tvPriceHeader;
    @ViewById
    protected TextView tvPrice;
    @ViewById
    protected TextView tvDesc;
    @ViewById
    protected LinearLayout lSignature;

    protected String TAG = FBaseSignature.class.getSimpleName();
    private static boolean isBitmapEmpty = false;
    protected MyView mv;
    private Bitmap signatureBitmap;
    private Paint mPaint;
    private boolean initFlag;

    @Click(R.id.btnClear)
    public void onBtnClearClick() {
        mv.clearDraw();
        mv.invalidate();
        setParamPaint();
    }

    public boolean isDrawBitmap() {
        if (mv == null)
            return false;
        return mv.isDrawBitmap();
    }

    @AfterViews
    public void init() {
        ViewTreeObserver observer = lSignature.getViewTreeObserver();
        if (observer != null) {
            observer.addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() {
                @Override
                public void onGlobalLayout() {
                    Log.d(TAG, "onGlobalLayout");
                    if (!initFlag) {
                        if (lSignature.getWidth() != 0) {
                            setParamPaint();
                            initPaint();
                            initFlag = true;
                        }
                    }
                }
            });
        }

        if (Global.isTablet(context)) {
            Display display = ((FragmentActivity) context).getWindowManager()
                    .getDefaultDisplay();
            Point size = new Point();
            display.getSize(size);
            int width = size.x;
            int height = size.y;
            int signSize = width > height ? height : width;

            Resources r = getResources();
            float px = TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP,
                    112, r.getDisplayMetrics());

            signSize -= px;
            LayoutParams params = (RelativeLayout.LayoutParams) lSignature
                    .getLayoutParams();
            params.addRule(RelativeLayout.CENTER_IN_PARENT, RelativeLayout.TRUE);
            params.width = signSize;
            params.height = signSize;
            lSignature.setLayoutParams(params);
        }
    }

    protected void initPaint() {
        mv = new MyView(context);
        lSignature.addView(mv);
    }

    protected void setParamPaint() {
        mPaint = new Paint();
        if (mPaint != null) {
            mPaint.setAntiAlias(true);
            mPaint.setDither(true);
            mPaint.setColor(Color.BLACK);
            mPaint.setStyle(Paint.Style.STROKE);
            mPaint.setStrokeJoin(Paint.Join.ROUND);
            mPaint.setStrokeCap(Paint.Cap.ROUND);
            mPaint.setStrokeWidth(3);
        }
    }

    public class MyView extends View {

        private static final float TOUCH_TOLERANCE = 4;

        private float mX, mY;
        private Bitmap mBitmap;
        private Canvas mCanvas;
        private Path mPath;
        private Paint mBitmapPaint;
        private boolean isDraw;

        public MyView(Context c) {
            super(c);

			/*
			 * int w = lPaint.getWidth(); int h = lPaint.getHeight();
			 */
            int w = lSignature.getWidth();
            int h = lSignature.getHeight();

            if (signatureBitmap != null && !isBitmapEmpty) {
                isDraw = true;
                // mBitmap = Bitmap.createBitmap(signatureBitmap);
                mBitmap = signatureBitmap.copy(Bitmap.Config.ARGB_8888, true);
            } else {
                isDraw = false;
                mBitmap = Bitmap.createBitmap(w, h, Bitmap.Config.ARGB_8888);
            }

            mCanvas = new Canvas(mBitmap);
            if (!isDraw)
                mCanvas.drawColor(Color.argb(50, 255, 255, 255));

            mPath = new Path();
            mBitmapPaint = new Paint(Paint.DITHER_FLAG);

        }

        public Bitmap getBitmap() {
            // mCanvas.drawColor(Color.argb(100, 255, 255, 255));
            return mBitmap;
        }

        @Override
        protected void onSizeChanged(int w, int h, int oldw, int oldh) {
            super.onSizeChanged(w, h, oldw, oldh);
        }

        @Override
        protected void onDraw(Canvas canvas) {
            // canvas.drawColor(Color.argb(100, 255, 255, 255));
            canvas.drawBitmap(mBitmap, 0, 0, mBitmapPaint);
            canvas.drawPath(mPath, mPaint);
        }

        public void clearDraw() {
            mBitmap.eraseColor(Color.TRANSPARENT);
            mPaint.reset();
            isDraw = false;
            mCanvas.drawColor(0, PorterDuff.Mode.CLEAR);
            mCanvas.drawColor(Color.argb(50, 255, 255, 255));
            isBitmapEmpty = true;
        }

        public boolean isDrawBitmap() {
            return isDraw;
        }

        private void touch_start(float x, float y) {
            mPath.reset();
            mPath.moveTo(x, y);
            mX = x;
            mY = y;
        }

        private void touch_move(float x, float y) {
            float dx = Math.abs(x - mX);
            float dy = Math.abs(y - mY);
            if (dx >= TOUCH_TOLERANCE || dy >= TOUCH_TOLERANCE) {
                isDraw = true;
                isBitmapEmpty = false;
                mPath.quadTo(mX, mY, (x + mX) / 2, (y + mY) / 2);
                mX = x;
                mY = y;
            }
            // mPath.lineTo(x, y);
            // mX = x;
            // mY = y;
        }

        private void touch_up() {
            mPath.lineTo(mX, mY);
            // commit the path to our offscreen
            mCanvas.drawPath(mPath, mPaint);
            // kill this so we don't double draw
            mPath.reset();
        }

        @Override
        public boolean onTouchEvent(MotionEvent event) {
            float x = event.getX();
            float y = event.getY();
            switch (event.getAction()) {
                case MotionEvent.ACTION_DOWN:
                    touch_start(x, y);
                    invalidate();
                    break;
                case MotionEvent.ACTION_MOVE:
                    touch_move(x, y);
                    invalidate();
                    break;
                case MotionEvent.ACTION_UP:
                    touch_up();
                    invalidate();
                    break;
            }
            return true;
        }
    }
}
