package com.lifepay.lifepayrp750xdemo.activities.rp750x;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Bundle;
import android.view.View;
import android.widget.TextView;

import com.lifepay.lib.LifePayApi;
import com.lifepay.lib.LifePayException;
import com.lifepay.lib.rest.params.PaymentParams;
import com.lifepay.lib.utils.Consts;
import com.lifepay.lifepayrp750xdemo.utils.ActivityUtils;
import com.lifepay.lifepayrp750xdemo.R;
import com.lifepay.lifepayrp750xdemo.activities.MainActivity_;
import com.lifepay.lifepayrp750xdemo.activities.PaymentSummaryActivity_;
import com.lifepay.lifepayrp750xdemo.activities.base.BaseFragmentActivity;
import com.lifepay.lifepayrp750xdemo.activities.rp750x.FBaseRP750xPayment.RP750xPaymentIntf;
import com.lifepay.lifepayrp750xdemo.activities.rp750x.FBaseCancelableSignature.FBaseCancelableSignatureIntf;
import com.lifepay.lifepayrp750xdemo.activities.base.FBaseMenuBar;
import com.lifepay.lifepayrp750xdemo.activities.base.FBaseMenuBar.FBaseMenuBarInterface;

import org.androidannotations.annotations.AfterViews;
import org.androidannotations.annotations.EActivity;
import org.androidannotations.annotations.FragmentById;
import org.androidannotations.annotations.ViewById;

@EActivity
public abstract class BaseRP750xPaymentActivity extends BaseFragmentActivity {

    @FragmentById
    protected FBaseMenuBar fMenuBar;
    @FragmentById
    protected FBaseRP750xPayment fCardPayment;
    @FragmentById
    protected FRP750xBluetoothSelect fBluetoothSelect;

    @FragmentById
    protected FBaseCancelableSignature fSignature;
    @ViewById
    protected TextView tvConnectionError;
    protected BroadcastReceiver networkReceiver;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        // TODO Auto-generated method stub
        super.onCreate(savedInstanceState);

        networkReceiver = new BroadcastReceiver() {
            public void onReceive(Context context, Intent intent) {
                if (intent.getExtras() != null) {
                    NetworkInfo ni = (NetworkInfo) intent.getExtras().get(ConnectivityManager.EXTRA_NETWORK_INFO);
                    if (ni != null && ni.getState() == NetworkInfo.State.CONNECTED) {
                        onNetworkConnected();
                    }
                }
                if (intent.getExtras().getBoolean(ConnectivityManager.EXTRA_NO_CONNECTIVITY, Boolean.FALSE)) {
                    onNetworkDisconnected();
                }
            }
        };

        registerReceiver(networkReceiver, new IntentFilter("android.net.conn.CONNECTIVITY_CHANGE"));
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (networkReceiver != null)
            unregisterReceiver(networkReceiver);
    }

    protected void onNetworkConnected() {
        tvConnectionError.setVisibility(View.GONE);
    }

    protected void onNetworkDisconnected() {
        tvConnectionError.setVisibility(View.VISIBLE);
    }

    @AfterViews
    public void init() {
        fCardPayment.setIntf(new RP750xPaymentIntf() {

            @Override
            public void onSuccess() {
                onPaymentSuccess();
            }

            @Override
            public void onError() {
                forceBack();
            }

            @Override
            public void onStop() {
                forceBack();
            }

            @Override
            public void onShowSignature() {
                fSignature.show();
            }

            @Override
            public void onShowBluetoothSelect() {
                fBluetoothSelect.show();
                fBluetoothSelect.updateDevicesList(LifePayApi.getInstance().pinPad().getBoundedDevices());
            }
        });

        fSignature.setIntf(new FBaseCancelableSignatureIntf() {

            @Override
            public void signature(byte[] signature) {
                try {
                    LifePayApi.getInstance().pinPad().setSignature(signature, context);
                    fSignature.hide();
                } catch (LifePayException e) {
                }
            }

            @Override
            public void cancel() {
                LifePayApi.getInstance().pinPad().cancelSignature();
                fSignature.hide();
            }

            @Override
            public String getDescription() {
                PaymentParams p = fCardPayment.getPaymentParams();
                return p.getDescription();
            }

            @Override
            public String getAmount() {
                PaymentParams p = fCardPayment.getPaymentParams();
                return String.format("%.2f", p.getAmount()) + " " + Consts.CurrencyString.RUB;
            }

            @Override
            public String getAmountTitle() {
                PaymentParams p = fCardPayment.getPaymentParams();
                return p.getOperationType() == LifePayApi.OperationType.PAYMENT ? "Сумма к оплате:" : "Сумма к возврату:";
            }
        });
        fSignature.hide();

        fBluetoothSelect.setIntf(new FRP750xBluetoothSelect.FP750xBluetoothSelectIntf() {
            @Override
            public void select(int index) {
                fBluetoothSelect.hide();
                fCardPayment.show();
                LifePayApi.getInstance().pinPad().selectDevice(index);
            }

            @Override
            public void update() {
                fBluetoothSelect.updateDevicesList(LifePayApi.getInstance().pinPad().getBoundedDevices());
            }
        });
        fBluetoothSelect.hide();

        fMenuBar.setIntf(new FBaseMenuBarInterface() {
            @Override
            public void onButtonClick(int id) {
                switch (id) {
                    case R.id.btnBack:
                        back();
                        break;
                }
            }
        });
    }

    @Override
    public void onResume() {
        super.onResume();
        fCardPayment.show();
    }

    protected void onPaymentSuccess() {
        ActivityUtils.startActivity(this, PaymentSummaryActivity_.class);
    }

    @Override
    public void back() {
        if (LifePayApi.getInstance().pinPad().canStop()) {
            LifePayApi.getInstance().pinPad().stopTransaction();
        }
    }

    protected void forceBack() {
        fCardPayment.hide();
        ActivityUtils.startActivity(this, MainActivity_.class);
        finish();
    }

}
