package com.lifepay.lifepayrp750xdemo.activities.rp750x;

import android.app.Activity;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.widget.TextView;

import com.lifepay.lib.LifePayApi;
import com.lifepay.lib.LifePayApi.OperationType;
import com.lifepay.lib.LifePayException;
import com.lifepay.lib.models.RP750xPaymentModelIntf.PaymentModelCallback;
import com.lifepay.lib.TransactionResult;
import com.lifepay.lib.reader.utils.drd50.UiHelper;
import com.lifepay.lib.rest.params.PaymentParams;
import com.lifepay.lifepayrp750xdemo.TestData;
import com.lifepay.lifepayrp750xdemo.R;
import com.lifepay.lifepayrp750xdemo.activities.base.BaseFragment;

import com.lifepay.lifepayrp750xdemo.utils.uiUtilsHelper;

import org.androidannotations.annotations.EFragment;
import org.androidannotations.annotations.UiThread;
import org.androidannotations.annotations.ViewById;

import java.util.List;

@EFragment
public abstract class FBaseRP750xPayment extends BaseFragment {

    protected String TAG = FBaseRP750xPayment.class.getSimpleName();
    @ViewById
    protected TextView tvTitle;
    protected OperationType currentOperation;
    private RP750xPaymentIntf intf;

    @Override
    public void hide() {
        super.hide();
    }

    @Override
    public void show() {
        super.show();
        startLifePay();
    }

    private void startLifePay() {
        try {
            LifePayApi.getInstance().pinPad().startTransaction(context,
                    getPaymentParams(), getPaymentModelCallback());
        } catch (LifePayException e) {
            showError(e.getMessage());
        }
    }

    @UiThread
    protected void setInstruction(String text) {
        tvTitle.setText(text);
    }

    @UiThread
    protected void showApplicationSelection(final List<String> appLabels) {
        new Thread(new Runnable() {
            public void run() {
                int index = UiHelper.selectDialogItemOnThread(
                        (Activity) context, R.string.select_application,
                        appLabels.toArray(new String[appLabels.size()]));
                if (index >= 0) {
                    LifePayApi.getInstance().pinPad().selectApplication(index);
                } else {
                    LifePayApi.getInstance().pinPad().cancelSelectApplication();
                }
            }
        }).start();
    }

    protected PaymentModelCallback getPaymentModelCallback() {
        return new PaymentModelCallback() {
            @Override
            public void connecting() {
                setInstruction("Подключение...");
            }

            @Override
            public void selectDevice() {
                setInstruction("");
                intf.onShowBluetoothSelect();
            }

            @Override
            public void configuring(){
                setInstruction("Настройка...");
            }

            @Override
            public void applicationSelection(List<String> appLabels) {
                setInstruction("");
                showApplicationSelection(appLabels);
            }

            @Override
            public void signatureRequest() {
                setInstruction("");
                intf.onShowSignature();
            }

            @Override
            public void stopping() {
                setInstruction("Закрытие соединения с терминалом...");
            }

            @Override
            public void stopped() {
                intf.onStop();
            }

            @Override
            public void transactionSuccess(TransactionResult result) {
                if (currentOperation == OperationType.PAYMENT) {
                    TestData.LAST_TRANSACTION_AMOUNT = getPaymentParams().getAmount();
                    TestData.TRANSACTION_INFO = result.getTransactionInfo();
                } else {
                    TestData.TRANSACTION_INFO = null;
                    TestData.REFUND_INFO = result.getTransactionInfo();
                }
                next();
            }

            @Override
            public void transactionError(final TransactionResult result) {
                showTransactionError(result);
            }

            @Override
            public void waitCard() {
                setInstruction("Терминал подключен, вставьте карту...");
            }

            @Override
            public void terminalProcessing() {
                setInstruction("Следуйте инструкциям на экране терминала...");
            }

            @Override
            public void transactionStart(){
                setInstruction("Обработка транзакции...");
            }

            @Override
            public void authError(String error) {
                showAuthError();
            }
        };
    }
    private double amount_ = TestData.AMOUNT();
    protected PaymentParams getPaymentParams() {
        currentOperation = OperationType.PAYMENT;
        PaymentParams params = new PaymentParams(TestData.LOGIN,
                TestData.PASSWORD, null, null,
                TestData.DESCRIPTION, amount_, 0.0, 0.0, null,
                currentOperation, null);
        return params;
    }

    @UiThread
    protected void showTransactionError(final TransactionResult result) {
        setInstruction("");
        uiUtilsHelper.showErrorMessage(context, result.getError(), new OnClickListener() {
                    public void onClick(DialogInterface dialog, int which) {
                        result.errorReaded();
                        exit();
                    }
                });
    }

    @UiThread
    protected void showAuthError() {
        setInstruction("");
        uiUtilsHelper.showErrorMessage(context, "Неправильный логин или пароль", new OnClickListener() {
                    public void onClick(DialogInterface dialog, int which) {
                        exit();
                    }
                });
    }

    @UiThread
    protected void next() {
        if (intf != null) intf.onSuccess();
    }

    @UiThread
    protected void exit() {
        if (intf != null) intf.onError();
    }

    @UiThread
    protected void showError(String msg) {
        setInstruction("");
        uiUtilsHelper.showAlert(context, msg,
                new OnClickListener() {
                    public void onClick(DialogInterface dialog, int which) {
                        exit();
                    }
                });
    }

    public void setIntf(RP750xPaymentIntf intf) {
        this.intf = intf;
    }

    public interface RP750xPaymentIntf {
        void onSuccess();
        void onError();
        void onStop();
        void onShowSignature();
        void onShowBluetoothSelect();
    }
}
