package com.lifepay.lifepayrp750xdemo.activities.rp750x;

import android.content.Intent;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.LinearLayout;
import android.widget.ListAdapter;
import android.widget.ListView;

import com.lifepay.lifepayrp750xdemo.R;
import com.lifepay.lifepayrp750xdemo.activities.base.BaseFragment;

import org.androidannotations.annotations.AfterViews;
import org.androidannotations.annotations.Click;
import org.androidannotations.annotations.EFragment;
import org.androidannotations.annotations.UiThread;
import org.androidannotations.annotations.ViewById;

import java.util.List;

@EFragment(R.layout.f_rp750x_bluetooth_select)
public class FRP750xBluetoothSelect extends BaseFragment {

    protected String TAG = FRP750xBluetoothSelect.class.getSimpleName();

    @ViewById
    protected LinearLayout llPairedEmpty;
    @ViewById
    protected LinearLayout llPaired;
    @ViewById
    protected ListView lwPaired;

    private FP750xBluetoothSelectIntf intf;

    public void setIntf(FP750xBluetoothSelectIntf intf) {
        this.intf = intf;
    }

    @AfterViews
    protected void init() {
        lwPaired.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> adapterView,
                                    View view, int i, long l) {
                intf.select(i);
            }
        });
    }

    @Click(R.id.btnSettings)
    public void onSettingsClick() {
        Intent intentOpenBluetoothSettings = new Intent();
        intentOpenBluetoothSettings.setAction(android.provider.Settings.ACTION_BLUETOOTH_SETTINGS);
        startActivity(intentOpenBluetoothSettings);
    }

    @UiThread
    public void updateDevicesList(List<String> devices) {
        if (devices.size() > 0) {
            ListAdapter adapter = lwPaired.getAdapter();
            if (adapter == null) {
                lwPaired.setAdapter(new BluetoothDeviceAdapter(context, devices));
                adapter = lwPaired.getAdapter();
            } else {
                ((BluetoothDeviceAdapter) adapter).clear();
                for (String str : devices) {
                    ((BluetoothDeviceAdapter) adapter).insert(str, adapter.getCount());
                }
                ((BluetoothDeviceAdapter) adapter).setDeviceNames(devices);
                ((BluetoothDeviceAdapter) adapter).notifyDataSetChanged();
            }

            int numberOfItems = adapter.getCount();
            // Get total height of all items.
            int totalItemsHeight = 0;
            for (int itemPos = 0; itemPos < numberOfItems; itemPos++) {
                View item = adapter.getView(itemPos, null, lwPaired);
                item.measure(0, 0);
                totalItemsHeight += item.getMeasuredHeight();
            }

            // Get total height of all item dividers.
            int totalDividersHeight = lwPaired.getDividerHeight() *
                    (numberOfItems - 1);

            // Set list height.
            ViewGroup.LayoutParams params = lwPaired.getLayoutParams();
            params.height = totalItemsHeight + totalDividersHeight;
            lwPaired.setLayoutParams(params);
            lwPaired.requestLayout();

            llPairedEmpty.setVisibility(View.GONE);
            llPaired.setVisibility(View.VISIBLE);
        } else {
            llPairedEmpty.setVisibility(View.VISIBLE);
            llPaired.setVisibility(View.GONE);
        }
    }

    @Override
    public void onResume() {
        super.onResume();
        if (intf != null && this.getView() != null
                && this.getView().getVisibility() == View.GONE) intf.update();
    }

    public interface FP750xBluetoothSelectIntf {
        void select(int index);
        void update();
    }

}